"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const jovo_core_1 = require("jovo-core");
const _merge = require("lodash.merge");
const speechmarkdown_js_1 = require("speechmarkdown-js");
class SpeechMarkdown {
    constructor(config) {
        this.config = {
            options: {
                includeFormatterComment: false,
                includeParagraphTag: false,
                includeSpeakTag: true,
                platform: '',
                preserveEmptyLines: true,
            }
        };
        if (config) {
            this.config = _merge(this.config, config);
        }
    }
    static getPlatform(jovo) {
        let platform;
        switch (jovo.getType()) {
            case 'AlexaSkill':
                platform = 'amazon-alexa';
                break;
            case 'GoogleAction':
                platform = 'google-assistant';
                break;
            case 'BixbyCapsule':
                platform = 'samsung-bixby';
                break;
            default: platform = '';
        }
        return platform;
    }
    install(app) {
        jovo_core_1.Jovo.prototype.$speechMarkdown = undefined;
        // initialize SpeechMarkdown instance
        app.middleware('after.platform.init').use((handleRequest) => {
            const options = Object.assign({}, this.config.options, { platform: SpeechMarkdown.getPlatform(handleRequest.jovo) });
            handleRequest.jovo.$speechMarkdown = new speechmarkdown_js_1.SpeechMarkdown(options);
        });
        app.on('before.platform.output', (handleRequest) => {
            if (handleRequest.jovo.$speechMarkdown) {
                if (handleRequest.jovo.$output.tell) {
                    handleRequest.jovo.$output.tell.speech = handleRequest.jovo.$speechMarkdown.toSSML(handleRequest.jovo.$output.tell.speech.toString());
                    // tmp?
                    handleRequest.jovo.$output.tell.speech = handleRequest.jovo.$output.tell.speech.replace(/\n/g, '');
                }
                if (handleRequest.jovo.$output.ask) {
                    handleRequest.jovo.$output.ask.speech = handleRequest.jovo.$speechMarkdown.toSSML(handleRequest.jovo.$output.ask.speech.toString());
                    handleRequest.jovo.$output.ask.reprompt = handleRequest.jovo.$speechMarkdown.toSSML(handleRequest.jovo.$output.ask.reprompt.toString());
                    // tmp?
                    handleRequest.jovo.$output.ask.speech = handleRequest.jovo.$output.ask.speech.replace(/\n/g, '');
                    handleRequest.jovo.$output.ask.reprompt = handleRequest.jovo.$output.ask.reprompt.replace(/\n/g, '');
                }
            }
        });
    }
}
exports.SpeechMarkdown = SpeechMarkdown;
//# sourceMappingURL=SpeechMarkdown.js.map